@@ -61,19 +61,3 @@ def upgrade_apps():
     project_file_path = project_path.joinpath("kamaqi.json").resolve()
 
     add_kamaqi_file(project_file_path,project_data)
-
-
-@app.command(name="tables",
-             help="Upgrade your database tables")
-def upgrade_tables(message:str=typer.Option(...,"--message","-m")):
-
-    project_data:dict = read_project_file()
-    project_name:str = project_data["project_name"]
-
-    if project_data["project_type"] == "normal":
-        os.system(f"""alembic revision --autogenerate -m"{message}" """)
-        os.system("alembic upgrade head")
-
-    if project_data["project_type"] == "docker":
-        os.system(f"""docker-compose exec {project_name} alembic revision --autogenerate -m"{message}" """)
-        os.system(f"docker-compose exec {project_name} alembic upgrade head")
